==> nodejs_interop-0.4.0.tar.gz: lib/src/io/link.dart <==
part of nodejs_interop.io;

/// A reference to a symbolic link on the file system.
class Link extends FileSystemEntity implements f.Link {

  /// Creates a new symbolic link.
  Link(String path): super(path);

  /// Creates a new symbolic link from the specified [uri].
  Link.fromUri(Uri uri): this(uri.toFilePath(windows: const Platform().isWindows));

  /// A [File] whose path is the absolute path to this entity.
  @override
  Link get absolute => new Link(_path.resolve(path));

  /// Creates the link.
  /// Returns a [Future] that completes with the link when it has been created.
  /// If the link exists, the future will complete with an error.
  ///
  /// If [recursive] is `false`, the link is created only if all directories in its [path] exist.
  /// If [recursive] is `true`, all non-existing path components are created.
  /// The directories in the path of [target] are not affected, unless they are also in [path].
  @override
  Future<Link> create(String target, {bool recursive = false}) async {
    if (recursive) await parent.create(recursive: true);

    var completer = new Completer();
    _fs.symlink(target, path, allowInterop(([error]) {
      if (error == null) completer.complete(this);
      else completer.completeError(new f.FileSystemException(error.message, path));
    }));

    return completer.future;
  }

  /// Synchronously creates the link.
  /// Calling [createSync] on an existing link will throw an exception.
  ///
  /// If [recursive] is `false`, the link is created only if all directories in its [path] exist.
  /// If [recursive] is `true`, all non-existing path components are created.
  /// The directories in the path of [target] are not affected, unless they are also in [path].
  @override
  void createSync(String target, {bool recursive = false}) {
    if (recursive) parent.createSync(recursive: true);
    try { _fs.symlinkSync(target, path); }
    on JSError catch (error) { throw new f.FileSystemException(error.message, path); }
  }

  /// Deletes this link.
  @override
  Future<Link> delete({bool recursive = false}) {
    var completer = new Completer();
    _fs.unlink(path, allowInterop(([error]) {
      if (error == null) completer.complete(this);
      else completer.completeError(new f.FileSystemException(error.message, path));
    }));

    return completer.future;
  }

  /// Synchronously deletes this link.
  @override
  void deleteSync({bool recursive = false}) {
    try { _fs.unlinkSync(path); }
    on JSError catch (error) { throw new f.FileSystemException(error.message, path); }
  }

  /// Renames this link. Completes with a [Link] instance for the renamed link.
  @override
  Future<Link> rename(String newPath) {
    var completer = new Completer();
    _fs.rename(path, newPath, allowInterop(([error]) {
      if (error == null) completer.complete(new Link(newPath));
      else completer.completeError(new f.FileSystemException(error.message, newPath));
    }));

    return completer.future;
  }

  /// Synchronously renames this link. Returns a [Link] instance for the renamed link.
  @override
  Link renameSync(String newPath) {
    try {
      _fs.renameSync(path, newPath);
      return new Link(newPath);
    }

    on JSError catch (error) {
      throw new f.FileSystemException(error.message, newPath);
    }
  }

  /// Gets the target of the link. Returns a [Future] that completes with the path to the target.
  ///
  /// If the returned target is a relative path, it is relative to the directory containing the link.
  /// If the link does not exist, or is not a link, the future completes with a [FileSystemException].
  @override
  Future<String> target() {
    var completer = new Completer();
    _fs.readlink(path, allowInterop((error, [target]) {
      if (error == null) completer.complete(target);
      else completer.completeError(new f.FileSystemException(error.message, path));
    }));

    return completer.future;
  }

  /// Synchronously gets the target of the link. Returns the path to the target.
  ///
  /// If the returned target is a relative path, it is relative to the directory containing the link.
  /// If the link does not exist, or is not a link, throws a [FileSystemException].
  @override
  String targetSync() {
    try { return _fs.readlinkSync(path); }
    on JSError catch (error) { throw new f.FileSystemException(error.message, path); }
  }

  /// Updates the link.
  /// Returns a [Future] that completes with the link when it has been updated.
  /// Calling [update] on a non-existing link will complete its returned future with an exception.
  @override
  Future<Link> update(String target) async {
    await delete();
    await create(target);
    return this;
  }

  /// Synchronously updates the link. Calling [updateSync] on a non-existing link will throw an exception.
  @override
  void updateSync(String target) {
    deleteSync();
    createSync(target);
  }
}

==> nodejs_interop-0.5.0.tar.gz: lib/src/io/link.dart <==
part of nodejs_interop.io;

/// A reference to a symbolic link on the file system.
class Link extends FileSystemEntity implements f.Link {

  /// Creates a new symbolic link.
  Link(String path): super(path);

  /// Creates a new symbolic link from the specified [uri].
  Link.fromUri(Uri uri): this(uri.toFilePath(windows: const Platform().isWindows));

  /// A [Link] whose path is the absolute path to this entity.
  @override
  Link get absolute => new Link(_path.resolve(path));

  /// Creates the link.
  /// Returns a [Future] that completes with the link when it has been created.
  /// If the link exists, the future will complete with an error.
  ///
  /// If [recursive] is `false`, the link is created only if all directories in its [path] exist.
  /// If [recursive] is `true`, all non-existing path components are created.
  /// The directories in the path of [target] are not affected, unless they are also in [path].
  @override
  Future<Link> create(String target, {bool recursive = false}) async {
    if (recursive) await parent.create(recursive: true);

    var completer = new Completer<Link>();
    _fs.symlink(target, path, allowInterop(([error]) {
      if (error == null) completer.complete(this);
      else completer.completeError(new f.FileSystemException(error.message, path));
    }));

    return completer.future;
  }

  /// Synchronously creates the link.
  /// Calling [createSync] on an existing link will throw an exception.
  ///
  /// If [recursive] is `false`, the link is created only if all directories in its [path] exist.
  /// If [recursive] is `true`, all non-existing path components are created.
  /// The directories in the path of [target] are not affected, unless they are also in [path].
  @override
  void createSync(String target, {bool recursive = false}) {
    if (recursive) parent.createSync(recursive: true);
    try { _fs.symlinkSync(target, path); }
    on JSError catch (error) { throw new f.FileSystemException(error.message, path); }
  }

  /// Deletes this link.
  @override
  Future<Link> delete({bool recursive = false}) {
    var completer = new Completer<Link>();
    _fs.unlink(path, allowInterop(([error]) {
      if (error == null) completer.complete(this);
      else completer.completeError(new f.FileSystemException(error.message, path));
    }));

    return completer.future;
  }

  /// Synchronously deletes this link.
  @override
  void deleteSync({bool recursive = false}) {
    try { _fs.unlinkSync(path); }
    on JSError catch (error) { throw new f.FileSystemException(error.message, path); }
  }

  /// Renames this link. Completes with a [Link] instance for the renamed link.
  @override
  Future<Link> rename(String newPath) {
    var completer = new Completer<Link>();
    _fs.rename(path, newPath, allowInterop(([error]) {
      if (error == null) completer.complete(new Link(newPath));
      else completer.completeError(new f.FileSystemException(error.message, newPath));
    }));

    return completer.future;
  }

  /// Synchronously renames this link. Returns a [Link] instance for the renamed link.
  @override
  Link renameSync(String newPath) {
    try {
      _fs.renameSync(path, newPath);
      return new Link(newPath);
    }

    on JSError catch (error) {
      throw new f.FileSystemException(error.message, newPath);
    }
  }

  /// Gets the target of the link. Returns a [Future] that completes with the path to the target.
  ///
  /// If the returned target is a relative path, it is relative to the directory containing the link.
  /// If the link does not exist, or is not a link, the future completes with a [FileSystemException].
  @override
  Future<String> target() {
    var completer = new Completer<String>();
    _fs.readlink(path, allowInterop((error, [target]) {
      if (error == null) completer.complete(target);
      else completer.completeError(new f.FileSystemException(error.message, path));
    }));

    return completer.future;
  }

  /// Synchronously gets the target of the link. Returns the path to the target.
  ///
  /// If the returned target is a relative path, it is relative to the directory containing the link.
  /// If the link does not exist, or is not a link, throws a [FileSystemException].
  @override
  String targetSync() {
    try { return _fs.readlinkSync(path); }
    on JSError catch (error) { throw new f.FileSystemException(error.message, path); }
  }

  /// Updates the link.
  /// Returns a [Future] that completes with the link when it has been updated.
  /// Calling [update] on a non-existing link will complete its returned future with an exception.
  @override
  Future<Link> update(String target) async {
    await delete();
    await create(target);
    return this;
  }

  /// Synchronously updates the link. Calling [updateSync] on a non-existing link will throw an exception.
  @override
  void updateSync(String target) {
    deleteSync();
    createSync(target);
  }
}
